@@ -36,7 +36,6 @@
 #include <Lum/Dialog.h>
 #include <Lum/Panel.h>
 #include <Lum/Space.h>
-#include <Lum/WindowGroup.h>
 
 #include "Configuration.h"
 #include "Selector.h"
@@ -135,20 +134,6 @@ public:
 
   ~MainDialog()
   {
-    UnattachModel(timer);
-    UnattachModel(stopAction);
-    UnattachModel(restartAction);
-    UnattachModel(startAction);
-    UnattachModel(aboutAction);
-
-    UnattachModel(value->GetClickAction());
-
-    UnattachModel(minutes);
-    UnattachModel(seconds);
-
-    UnattachModel(GetClosedAction());
-    UnattachModel(GetOpenedAction());
-
     delete beepSound;
   }
 
@@ -236,10 +221,6 @@ public:
     Lum::Button      *button;
     Lum::ButtonRow   *buttonRow;
     Lum::Panel       *panel;
-    Lum::WindowGroup *wGroup;
-
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
 
     panel=new Lum::VPanel();
     panel->SetFlex(true,true);
@@ -253,11 +234,6 @@ public:
     buttonRow=new Lum::ButtonRow();
     buttonRow->SetFlex(true,false);
 
-    button=new Lum::Button(_ld(dlgButtonAbout));
-    button->SetFlex(true,true);
-    button->SetModel(aboutAction);
-    buttonRow->AddOptional(button);
-
     button=new Lum::Button(_(L"BUTTON_START",L"_Start"));
     button->SetFlex(true,true);
     button->SetModel(startAction);
@@ -273,16 +249,21 @@ public:
     button->SetModel(stopAction);
     buttonRow->Add(button);
 
-    button=new Lum::Button(_ld(dlgButtonQuit));
-    button->SetFlex(true,true);
-    button->SetModel(GetClosedAction());
-    buttonRow->Add(button);
-
     panel->Add(buttonRow);
 
-    wGroup->SetMain(panel);
+    SetMain(panel);
 
-    SetTop(wGroup);
+    Lum::MenuDesc *menu=new Lum::MenuDesc();
+
+    menu
+      ->AddMenuItemSub(_ld(menuProject))
+        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(_ld(menuHelp))
+        ->AddMenuItemAction(_ld(menuHelpHelp),NULL)
+        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+
+    SetMenu(menu);
 
     SetState(stateStoped);
 
