@@ -32,7 +32,6 @@
 #include <Lum/Space.h>
 #include <Lum/Table.h>
 #include <Lum/TextValue.h>
-#include <Lum/WindowGroup.h>
 
 #include "Configuration.h"
 
@@ -74,21 +73,6 @@ Selector::Selector(Lum::Model::Int* minutes, Lum::Model::Int *seconds)
   AttachModel(GetClosedAction());
 }
 
-Selector::~Selector()
-{
-  UnattachModel(GetClosedAction());
-
-  UnattachModel(okAction);
-  UnattachModel(removeAction);
-  UnattachModel(updateAction);
-  UnattachModel(addAction);
-
-  UnattachModel(selection);
-
-  UnattachModel(seconds);
-  UnattachModel(minutes);
-}
-
 std::wstring Selector::GetTimeString(size_t minutes, size_t seconds) const
 {
   std::wstring tmp;
@@ -109,7 +93,6 @@ void Selector::PreInit()
   Lum::ButtonRow        *buttonRow;
   Lum::Label            *label;
   Lum::Panel            *panel,*horiz,*vert;
-  Lum::WindowGroup      *container;
   Lum::Slider           *slider;
   Lum::Table            *table;
   Lum::TextValue        *value;
@@ -192,24 +175,11 @@ void Selector::PreInit()
 
   panel->Add(new Lum::VSpace());
 
-  buttonRow=new Lum::ButtonRow();
+  buttonRow=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
   buttonRow->SetFlex(true,false);
-
-  button=new Lum::Button(_ld(dlgButtonOk));
-  button->SetFlex(true,true);
-  button->SetModel(okAction);
-  buttonRow->Add(button);
-
-  button=new Lum::Button(_ld(dlgButtonCancel));
-  button->SetFlex(true,true);
-  button->SetModel(GetClosedAction());
-  buttonRow->Add(button);
   panel->Add(buttonRow);
 
-  container=new Lum::WindowGroup();
-  container->SetMain(panel);
-
-  SetTop(container);
+  SetMain(panel);
 
   Dialog::PreInit();
 }
