@@ -25,6 +25,7 @@ StopWatch::StopWatch()
  : clickAction(new Lum::Model::Action()),
    blinkTimer(new Lum::Model::Action()),
    alarmColor(1.0,0,0,Lum::OS::Display::textColor),
+   alarm(false),
    showInvert(false)
 {
   if (Lum::OS::display->GetType()==Lum::OS::Display::typeTextual) {
@@ -34,18 +35,13 @@ StopWatch::StopWatch()
     }
   else {
     minFont=Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                      1000);
+                                      500);
     font=minFont;
   }
 
   AttachModel(blinkTimer);
 }
 
-StopWatch::~StopWatch()
-{
-  UnattachModel(blinkTimer);
-}
-
 Lum::Model::Action* StopWatch::GetClickAction() const
 {
   return clickAction.Get();
@@ -162,14 +158,18 @@ void StopWatch::Draw(int x, int y, size_t w, size_t h)
   Lum::OS::DrawInfo   *draw=GetDrawInfo();
   Lum::OS::FontExtent extent;
 
-  DrawBackground(x,y,w,h);
-
   draw->PushFont(font,Lum::OS::Font::bold);
 
   if (alarm && showInvert) {
+    DrawBackground(x,y,w,h);
     draw->PushForeground(alarmColor);
   }
   else if (alarm) {
+    draw->PushClipBegin(x,y,w,h);
+    draw->SubClipRegion(this->x,this->y,this->width,this->height);
+    DrawBackground(x,y,w,h);
+    draw->PopClip();
+
     draw->PushForeground(alarmColor);
     draw->FillRectangle(this->x,this->y,this->width,this->height);
     draw->PopForeground();
@@ -177,6 +177,7 @@ void StopWatch::Draw(int x, int y, size_t w, size_t h)
     draw->PushForeground(Lum::OS::Display::textColor);
   }
   else {
+    DrawBackground(x,y,w,h);
     draw->PushForeground(Lum::OS::Display::textColor);
   }
 
@@ -209,7 +210,7 @@ bool StopWatch::HandleMouseEvent(const Lum::OS::MouseEvent& event)
 
 void StopWatch::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
 {
-  if (model==blinkTimer) {
+  if (model==blinkTimer && blinkTimer->IsFinished()) {
     showInvert=!showInvert;
     Redraw();
   }
